@@ -825,14 +825,11 @@ djvu_document_find_find_text (EvDocumentFind   *document,
 	document_get_page_size (djvu_document, page->index, &width, &height, &dpi);
 	for (l = matches; l && l->data; l = g_list_next (l)) {
 		EvRectangle *r = (EvRectangle *)l->data;
-		gdouble      tmp;
+		gdouble tmp = r->y1;
 
-		tmp = r->y1;
-		
 		r->x1 *= 72.0 / dpi;
 		r->x2 *= 72.0 / dpi;
 
-		tmp = r->y1;
 		r->y1 = height - r->y2 * 72.0 / dpi;
 		r->y2 = height - tmp * 72.0 / dpi;
 	}
